#!/usr/bin/env python
#
#   break-lock.py
#   zfilenet
#
#   Copyright (C) 2008 Ross Light
#
#   This file is part of zfilenet.
#
#   zfilenet is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   zfilenet is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with zfilenet.  If not, see <http://www.gnu.org/licenses/>.
#

"""
Index server maintenence script

Breaks all locks associated with a file.

usage: break-lock.py database path [path2 ...]
"""

import os
import sys

import progtools

from zfilenet.indexserver import index

__author__ = 'Ross Light'
__date__ = 'August 12, 2008'
__all__ = ['main']

@progtools.reportexits
def main(args=None):
    # Get arguments
    if args is None:
        args = sys.argv[1:]
    if len(args) < 2:
        raise progtools.UsageError()
    # Connect to index
    if not os.path.exists(args[0]):
        print >> sys.stderr, "%s: Could not find database file" % \
            (progtools.get_program_name())
        return 1
    index_db = index.connect(args[0])
    session = index.create_session(bind=index_db)
    # Break locks
    for path in args[1:]:
        node = index.resolve_path(session, path)
        if node is None:
            print >> sys.stderr, "'%s' does not exist" % (path)
            continue
        print "Breaking locks for '%s'..." % (path)
        for lock in list(node.locks):
            print "Breaking lock <%s>" % (lock.name)
            node.unlock(lock)
    # Exit successfully
    session.close()
    return 0

if __name__ == '__main__':
    sys.exit(main())
